pub trait Commit {
// Required method
fn commit_words(&self) -> [u32; 8];
}Expand description
Values that can be committed to the public output registers (x10..x17).
pub trait Commit {
// Required method
fn commit_words(&self) -> [u32; 8];
}Values that can be committed to the public output registers (x10..x17).